@@ -22,7 +22,7 @@ class ReportFacade():
     )
 
     if not res.ok:
-      raise AssertionError('Could not create report')
+      raise AssertionError(res.content)
 
     return res.json()
 
@@ -37,6 +37,6 @@ class ReportFacade():
     )
 
     if not res.ok:
-      raise AssertionError('Could not list reports')
+      raise AssertionError(res.content)
 
     return res.json()
