@@ -8,9 +8,9 @@ from stoobly_agent.lib.utils.conditional_decorator import ConditionalDecorator
 
 from .app.api import run as run_api
 from .app.cli import ca_cert, config, feature, MainGroup, project, request
-from .app.cli.helpers.migrate_service import migrate as migrate_database
 from .app.proxy import INTERCEPT_MODES, run as run_proxy
 from .app.settings import Settings
+from .lib.orm.migrate_service import migrate as migrate_database
 
 settings = Settings.instance()
 is_remote = settings.cli.features.remote
@@ -52,8 +52,8 @@ if settings.cli.features.remote:
 )
 @ConditionalDecorator(lambda f: click.option('--api-url', help='API URL.')(f), is_remote)
 @ConditionalDecorator(lambda f: click.option('--headless', is_flag=True, default=False, help='Disable starting UI.')(f), is_remote)
-@click.option('--intercept-mode', help=', '.join(INTERCEPT_MODES))
-@click.option('--log-level', default='info', help='''
+@click.option('--intercept-mode', help=', '.join(INTERCEPT_MODES), type=click.Choice(INTERCEPT_MODES))
+@click.option('--log-level', default='info', type=click.Choice(['debug', 'info', 'warning', 'error']), help='''
     Log levels can be "debug", "info", "warning", or "error"
 ''')
 @click.option('--proxy-host', default='0.0.0.0', help='Address to bind proxy to.')
